# coding: utf-8

# flake8: noqa

"""
    aind-dataverse-service

     ## aind-dataverse-service  Service to pull data from Allen Institute's Dataverse database.  

    The version of the OpenAPI document: 0.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.0.3"

# import apis into sdk package
from aind_dataverse_service_client.api.default_api import DefaultApi
from aind_dataverse_service_client.api.healthcheck_api import HealthcheckApi

# import ApiClient
from aind_dataverse_service_client.api_response import ApiResponse
from aind_dataverse_service_client.api_client import ApiClient
from aind_dataverse_service_client.configuration import Configuration
from aind_dataverse_service_client.exceptions import OpenApiException
from aind_dataverse_service_client.exceptions import ApiTypeError
from aind_dataverse_service_client.exceptions import ApiValueError
from aind_dataverse_service_client.exceptions import ApiKeyError
from aind_dataverse_service_client.exceptions import ApiAttributeError
from aind_dataverse_service_client.exceptions import ApiException

# import models into sdk package
from aind_dataverse_service_client.models.entity_table_row import EntityTableRow
from aind_dataverse_service_client.models.http_validation_error import HTTPValidationError
from aind_dataverse_service_client.models.health_check import HealthCheck
from aind_dataverse_service_client.models.validation_error import ValidationError
from aind_dataverse_service_client.models.validation_error_loc_inner import ValidationErrorLocInner



# coding: utf-8

"""
    aind-dataverse-service

     ## aind-dataverse-service  Service to pull data from Allen Institute's Dataverse database.  

    The version of the OpenAPI document: 0.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from aind_dataverse_service_client.api.default_api import DefaultApi


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DefaultApi()

    def tearDown(self) -> None:
        pass

    def test_get_table(self) -> None:
        """Test case for get_table

        Get Table
        """
        pass

    def test_get_table_info(self) -> None:
        """Test case for get_table_info

        Get Table Info
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    aind-dataverse-service

     ## aind-dataverse-service  Service to pull data from Allen Institute's Dataverse database.  

    The version of the OpenAPI document: 0.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from aind_dataverse_service_client.models.health_check import HealthCheck

class TestHealthCheck(unittest.TestCase):
    """HealthCheck unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> HealthCheck:
        """Test HealthCheck
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `HealthCheck`
        """
        model = HealthCheck()
        if include_optional:
            return HealthCheck(
                status = 'OK',
                service_version = '0.0.3'
            )
        else:
            return HealthCheck(
        )
        """

    def testHealthCheck(self):
        """Test HealthCheck"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
